@@ -11,7 +11,9 @@ use IO::File;
 use Mail::Address;
 use File::Spec;
 
-$VERSION = '0.182';
+use bytes;
+
+$VERSION = '0.184';
 
 %AUTOLOAD = (
   fqdn     => 1,
@@ -26,6 +28,16 @@ $NSLOOKUP_PAT = 'preference|serial|expire|mail\s+exchanger';
 
 # initialize if already loaded, better in prefork mod_perl environment
 $DNS_Method = defined $Net::DNS::VERSION ? 'Net::DNS' : '';
+unless ($DNS_Method) {
+    __PACKAGE__->_select_dns_method;
+}
+
+# initialize $Resolver if necessary
+if ($DNS_Method eq 'Net::DNS') {
+    unless (defined $Resolver) {
+        $Resolver = Net::DNS::Resolver->new;
+    }
+}
 
 sub new {
   my $class   = shift;
